Arrays
===============

These functions are applicable for general ND-arrays.

.. contents::
    :depth: 2
    :local:


.. currentmodule:: cr.nimble


Inner products
------------------------

.. autosummary::
    :toctree: _autosummary

    arr_vdot
    arr_rdot


Norms
---------------------

.. autosummary::
    :toctree: _autosummary


    arr_l1norm
    arr_l2norm
    arr_l2norm_sqr


Utilities
------------------------

.. autosummary::
    :toctree: _autosummary

    hermitian
    arr_largest_index
    arr2vec
    check_shapes_are_equal
